@@ -30,6 +30,7 @@
 
 #include "appchooserdialog.h"
 #include "appchooserrow.h"
+#include <adwaita.h>
 
 #define LOCATION_MAX_LENGTH 40
 #define INITIAL_LIST_SIZE 3
@@ -197,18 +198,10 @@ show_error_dialog (const gchar *primary,
 {
   GtkWidget *message_dialog;
 
-  message_dialog = gtk_message_dialog_new (parent, 0,
-                                           GTK_MESSAGE_ERROR,
-                                           GTK_BUTTONS_OK,
-                                           NULL);
-  g_object_set (message_dialog,
-                "text", primary,
-                "secondary-text", secondary,
-                NULL);
-  gtk_dialog_set_default_response (GTK_DIALOG (message_dialog), GTK_RESPONSE_OK);
+  message_dialog = adw_message_dialog_new (parent, primary, secondary);
+  adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (message_dialog), "ok", _("_Ok"));
+  adw_message_dialog_set_default_response (ADW_MESSAGE_DIALOG (message_dialog), "ok");
   gtk_window_present (GTK_WINDOW (message_dialog));
-  g_signal_connect (message_dialog, "response",
-                    G_CALLBACK (gtk_window_destroy), NULL);
 }
 
 static void
@@ -389,12 +382,12 @@ app_chooser_dialog_new (const char **choices,
     {
       g_autofree char *heading = NULL;
 
-      heading = g_strdup_printf (_("Choose an application to open the file “%s”."), short_location);
+      heading = g_strdup_printf (_("Choose an app to open the file “%s”."), short_location);
       gtk_label_set_label (GTK_LABEL (dialog->heading), heading);
     }
   else
     {
-      gtk_label_set_label (GTK_LABEL (dialog->heading), _("Choose an application."));
+      gtk_label_set_label (GTK_LABEL (dialog->heading), _("Choose an app."));
     }
 
   ensure_default_in_initial_list (choices, default_id);
@@ -411,12 +404,12 @@ app_chooser_dialog_new (const char **choices,
         {
           g_autofree char *label = NULL;
 
-          label = g_strdup_printf (_("No apps installed that can open “%s”. You can find more applications in Software"), short_location);
+          label = g_strdup_printf (_("No apps installed that can open “%s”. You can find more apps in Software"), short_location);
           gtk_label_set_label (GTK_LABEL (dialog->empty_label), label);
         }
       else
         {
-          gtk_label_set_label (GTK_LABEL (dialog->empty_label), _("No suitable app installed. You can find more applications in Software."));
+          gtk_label_set_label (GTK_LABEL (dialog->empty_label), _("No suitable app installed. You can find more apps in Software."));
         }
     }
   else
