@@ -382,6 +382,7 @@ create_input_capture_dialog (GDBusMethodInvocation *invocation,
                              const char            *session_handle,
                              unsigned int           capabilities)
 {
+  g_autoptr(GtkWindowGroup) window_group = NULL;
   InputCaptureDialogHandle *dialog_handle;
   ExternalWindow *external_parent;
   GdkSurface *surface;
@@ -407,6 +408,9 @@ create_input_capture_dialog (GDBusMethodInvocation *invocation,
   gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (fake_parent));
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
+  window_group = gtk_window_group_new ();
+  gtk_window_group_add_window (window_group, dialog);
+
   dialog_handle = g_new0 (InputCaptureDialogHandle, 1);
   dialog_handle->request = g_object_ref (request);
   dialog_handle->external_parent = external_parent;
