@@ -436,6 +436,7 @@ handle_print (XdpImplPrint          *object,
               GVariant              *arg_fd_in,
               GVariant              *arg_options)
 {
+  g_autoptr(GtkWindowGroup) window_group = NULL;
   g_autoptr(Request) request = NULL;
   const char *sender;
   GtkWindow *dialog;
@@ -506,6 +507,10 @@ handle_print (XdpImplPrint          *object,
                                                  GTK_PRINT_CAPABILITY_SCALE |
                                                  GTK_PRINT_CAPABILITY_NUMBER_UP
                                                  );
+
+  window_group = gtk_window_group_new ();
+  gtk_window_group_add_window (window_group, dialog);
+
   handle = g_new0 (PrintDialogHandle, 1);
   handle->impl = object;
   handle->invocation = invocation;
@@ -609,6 +614,7 @@ handle_prepare_print (XdpImplPrint          *object,
                       GVariant              *arg_page_setup,
                       GVariant              *arg_options)
 {
+  g_autoptr(GtkWindowGroup) window_group = NULL;
   g_autoptr(Request) request = NULL;
   const char *sender;
   GtkWindow *dialog;
@@ -619,6 +625,7 @@ handle_prepare_print (XdpImplPrint          *object,
   GdkSurface *surface;
   ExternalWindow *external_parent = NULL;
   GtkWidget *fake_parent;
+  const char *accept_label;
 
   sender = g_dbus_method_invocation_get_sender (invocation);
 
@@ -641,6 +648,12 @@ handle_prepare_print (XdpImplPrint          *object,
     modal = TRUE;
 
   dialog = GTK_WINDOW (gtk_print_unix_dialog_new (arg_title, NULL));
+  if (g_variant_lookup (arg_options, "accept_label", "&s", &accept_label))
+    {
+      GtkWidget *button = gtk_dialog_get_widget_for_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+      gtk_button_set_label (GTK_BUTTON (button), accept_label);
+    }
+
   gtk_window_set_transient_for (dialog, GTK_WINDOW (fake_parent));
   gtk_window_set_modal (dialog, modal);
   gtk_print_unix_dialog_set_manual_capabilities (GTK_PRINT_UNIX_DIALOG (dialog),
@@ -655,6 +668,9 @@ handle_prepare_print (XdpImplPrint          *object,
   gtk_print_unix_dialog_set_settings (GTK_PRINT_UNIX_DIALOG (dialog), settings);
   gtk_print_unix_dialog_set_page_setup (GTK_PRINT_UNIX_DIALOG (dialog), page_setup);
 
+  window_group = gtk_window_group_new ();
+  gtk_window_group_add_window (window_group, dialog);
+
   g_object_unref (settings);
   g_object_unref (page_setup);
 
