@@ -121,7 +121,7 @@ serialize_screen_cast_streams_as_restore_data (GPtrArray       *streams,
 
   g_variant_builder_open (impl_builder, G_VARIANT_TYPE ("a(uuv)"));
 
-  for (i = 0; i < streams->len; i++)
+  for (i = 0; streams && i < streams->len; i++)
     {
       ScreenCastStreamInfo *info = g_ptr_array_index (streams, i);
       GVariant *stream_variant;
@@ -359,6 +359,7 @@ create_screen_cast_dialog (ScreenCastSession     *session,
                            Request               *request,
                            const char            *parent_window)
 {
+  g_autoptr(GtkWindowGroup) window_group = NULL;
   ScreenCastDialogHandle *dialog_handle;
   ExternalWindow *external_parent;
   GdkSurface *surface;
@@ -386,6 +387,9 @@ create_screen_cast_dialog (ScreenCastSession     *session,
   gtk_window_set_transient_for (dialog, GTK_WINDOW (fake_parent));
   gtk_window_set_modal (dialog, TRUE);
 
+  window_group = gtk_window_group_new ();
+  gtk_window_group_add_window (window_group, dialog);
+
   dialog_handle = g_new0 (ScreenCastDialogHandle, 1);
   dialog_handle->session = session;
   dialog_handle->request = g_object_ref (request);
@@ -583,7 +587,7 @@ restore_screen_cast_streams (GVariantIter        *streams_iter,
         }
     }
 
-  return g_steal_pointer (&streams);
+  return streams->len > 0 ? g_steal_pointer (&streams) : NULL;
 }
 
 static gboolean
