@@ -106,7 +106,7 @@ on_file_copy_cb (GObject *source_object,
       goto out;
     }
 
-  destination = g_file_new_for_path (handle->picture_uri);
+  destination = g_file_new_for_uri (handle->picture_uri);
   if (!g_file_replace_contents (destination,
                                 contents,
                                 length,
@@ -133,8 +133,10 @@ set_wallpaper (WallpaperDialogHandle *handle,
                const gchar *uri)
 {
   g_autoptr(GFile) source = NULL;
+  g_autofree gchar *path = NULL;
 
-  handle->picture_uri = g_build_filename (g_get_user_config_dir (), "background", NULL);
+  path = g_build_filename (g_get_user_config_dir (), "background", NULL);
+  handle->picture_uri = g_filename_to_uri (path, NULL, NULL);
 
   source = g_file_new_for_uri (uri);
   g_file_load_contents_async (source,
